import java.util.ArrayList;

public class GraphPoint2D{

    private double x;
    private double y;
    private int updated;
    private ArrayList<Integer> neighbours;

    /*****
     * constructor for a McQueen point, saves coordinates, initiates update time and neighbour arraylist
     * @param x x-axis coordinate
     * @param y y-axis coordinate
     */
    public GraphPoint2D(double x, double y){
        this.x = x;
        this.y = y;
        this.updated = 0;
        neighbours = new ArrayList<>();
    }

    public double getX() {
        return x;
    }

    public double getY() {
        return y;
    }

    /***
     * getter for how many times got point updated
     * @return how many times got point updated
     */
    public int getTimesUpdated() {
        return updated;
    }

    public void setX(double x) {
        this.x = x;
    }

    public void setY(double y) {
        this.y = y;
    }

    /*****
     * deletes all neighbours of this point
     */
    public void nullNeighbours(){
        this.neighbours = new ArrayList<>();
    }

    public ArrayList<Integer> getNeighbours() {
        return neighbours;
    }

    public void addNeighbour(int index){
        this.neighbours.add(index);
    }

    public void update(){this.updated++;}

    public void restartUpdating(){
        this.updated = 0;
    }

    @Override
    public String toString() {
        return x + " " + y;
    }
}
